@@ -1,3 +1,5 @@
+from typing import Optional
+
 from pydantic import BaseModel
 
 
@@ -11,6 +13,7 @@ class WatchmenNotebook(BaseModel):
 
 
 
-
+test = WatchmenNotebook(name="A",storageLocation="")
+print(test)
 
 
