@@ -7,7 +7,7 @@ from ml_sdk.ml.sdk.watchmen.sdk import load_dataset_by_name
 def get_notebook():
     note_name = ipynbname.name()
     path = ipynbname.path()
-    notebook = WatchmenNotebook(name=note_name,storageLocation= path)
+    notebook = WatchmenNotebook(name=note_name,storageLocation=str(path))
     return notebook
 
 
